==> qmmp_0.6.3.orig.tar.gz: qmmp-0.6.3/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="257"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>關於 FFmpeg 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="259"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Qmmp FFmpeg 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="267"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="93"/>
        <source>FFmpeg Plugin</source>
        <translation>FFmpeg 插件</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="95"/>
        <source>FFmpeg Formats</source>
        <translation>FFmpeg 格式</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="260"/>
        <source>Compiled against libavformat-%1.%2.%3 and libavcodec-%4.%5.%6</source>
        <translation>編譯依賴 libavformat-%1.%2.%3 與 libavcodec-%4.%5.%6</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="99"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="53"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="100"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="53"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="100"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="54"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="101"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="54"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="101"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="117"/>
        <source>Sample rate</source>
        <translation>取樣率</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="66"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="117"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="67"/>
        <location filename="../ffmpegmetadatamodel.cpp" line="118"/>
        <source>Channels</source>
        <translation>聲音通道</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>FFmpeg 插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Input/ffmpeg/translations/ffmpeg_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="158"/>
        <source>FFmpeg Plugin</source>
        <translation>FFmpeg 外掛</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="160"/>
        <source>FFmpeg Formats</source>
        <translation>FFmpeg 格式</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="267"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>關於 FFmpeg 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="268"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Qmmp FFmpeg 聲訊插件</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="269"/>
        <source>Compiled against:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="282"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FFmpegMetaDataModel</name>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="50"/>
        <source>Length</source>
        <translation>長度</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="51"/>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="51"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
        <source>Bitrate</source>
        <translation>比特率</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="52"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Sample rate</source>
        <translation>取樣率</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="72"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../ffmpegmetadatamodel.cpp" line="73"/>
        <source>Channels</source>
        <translation>聲音通道</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>FFmpeg 插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>格式</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
